/*
 * Simulator of microcontrollers (hw.cc)
 *
 * Copyright (C) 1999,99 Drotos Daniel, Talker Bt.
 * 
 * To contact author send email to drdani@mazsola.iit.uni-miskolc.hu
 *
 */

/* This file is part of microcontroller simulator: ucsim.

UCSIM is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

UCSIM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with UCSIM; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA
02111-1307, USA. */
/*@1@*/

#include "ddconfig.h"

#include "stypes.h"
#include "hwcl.h"


cl_hw::cl_hw(class cl_uc *auc):
  cl_base()
{
  uc= auc;
}

cl_hw::~cl_hw(void)
{}

char *
cl_hw::id_string(void)
{
  return("Unknown hardware");
}

ulong
cl_hw::read(class cl_mem *mem, long addr)
{
  switch (mem->type)
    {
    case MEM_ROM:
      return(read_rom(mem, addr));
    case MEM_XRAM:
      return(read_xram(mem, addr));
    case MEM_IRAM:
      return(read_iram(mem, addr));
    case MEM_SFR:
      return(read_sfr(mem, addr));
    default:
      return(0);
    }
}

ulong
cl_hw::read_rom(class cl_mem *mem, long addr)
{
  return(mem->mem[addr]);
}

ulong
cl_hw::read_xram(class cl_mem *mem, long addr)
{
  return(mem->mem[addr]);
}

ulong
cl_hw::read_iram(class cl_mem *mem, long addr)
{
  return(mem->mem[addr]);
}

ulong
cl_hw::read_sfr(class cl_mem *mem, long addr)
{
  return(mem->mem[addr]);
}

void
cl_hw::write(class cl_mem *mem, long addr, ulong *val)
{
  switch (mem->type)
    {
    case MEM_ROM:
      write_rom(mem, addr, val);
      break;
    case MEM_XRAM:
      write_xram(mem, addr, val);
      break;
    case MEM_IRAM:
      write_iram(mem, addr, val);
      break;
    case MEM_SFR:
      write_sfr(mem, addr, val);
      break;
    }
}

void
cl_hw::write_rom(class cl_mem *mem, long addr, ulong *val)
{}

void
cl_hw::write_xram(class cl_mem *mem, long addr, ulong *val)
{}

void
cl_hw::write_iram(class cl_mem *mem, long addr, ulong *val)
{}

void
cl_hw::write_sfr(class cl_mem *mem, long addr, ulong *val)
{}


/* End of hw.cc */
